# Supplemental data for the paper `Line-focus solar concentration 10 times higher than the 2D thermodynamic limit`

This archive contains supplemental data underlying the paper titled `Line-focus solar concentration 10 times higher than the 2D thermodynamic limit`, submitted to `Optics Express`.

## Zemax OpticStudio Files

Zemax OpticStudio models of two design files are included as `Zemax/Concentrator 1.ZMX` and `Zemax/Concentrator 2.ZMX`.

The Zemax OpticStudio models include a Merit  Function used to evaluate optical efficiency at the discrete set of  angle of incidence  shown in Fig. 5 of the main document for `Concentrator 1`, and efficiency under normal incidence for `Concentrator 2`.

Please note that the merit function is only used as a convenient way to automatically evaluate efficiency at different concentrator configurations, and does not implement the optimization approach outlined in Section 3.1. It is not suitable for optimization using the built-in optimization  algorithms in Zemax OpticStudio.

## Underlying data for Fig. 3

Data underlying the Fig. 3 is included in json format in `Data/Fig 3.json`.  The json file contains a list of objects representing each line of the plot, with the following properties:

* `latitude` The latitude of this line
* `angle_of_incidence` List of angles of incidence
* `normalized_angular_insolation` The value of $e(\phi_L)$ corresponding to each item in `angle_of_incidence`

## Underlying data for Fig. 5

Data underlying Fig. 5a is included in json format in `Data/Fig 5.json`

The file contains two objects: `zemax_data` and `raytracer_data`.

`zemax_data` contains the following properties:

* `angle_of_incidence` List of angles of incidence
* `raw_efficiency`  Raw efficiency values as read from Zemax OpticStudio when opening `Zemax/Concentrator 1.ZMX`
* `correction_factor` Correction factor for the raw efficiency values, to account for how we define efficiency in terms of primary reflector area, and some of the rays from the Zemax OpticStudio model hit the inactive area in the middle of the concentrator instead of one of the primary reflectors.

`raytracer_data` contains the following properties:

* `angle_of_incidence` List of angles of incidence
* `efficiency` Efficiency, as simulated using our own raytracer.

Fig. 5b is made by combining the data for Fig. 5a with the data for Fig. 3.

## Underlying data for Fig .6

Data underlying the Fig. 6a is included in json format in `Data/Fig 6.json`.  The json file contains a list of objects representing each line of the plot, with the following properties:

* `optical_concentration`
* `efficiency` Efficiency, as a number between 0 and 1.
* `label`

Fig. 6b is simply a plot log-log plot of the numbers and concentration limits that are given in the paper.

## Underlying data for Fig. 7

Data underlying Fig. 7 is included as compressed numpy arrays in the `.npz` file format, in the file `Data/Fig_7.npz`. This file can be read using the `numpy.load` function.

The `.npz` file contains the following arrays

* `concentrator_1_efficiency_distribution` 2D numpy image of efficiency as a function of angle of incidence.
* `concentrator_1_extent` Extent of the efficiency distribution on the form `(xmin, xmax, ymin, ymax)`, for plotting with `matplotlib.pyplot.imshow`. The unit is milliradians.
* `concentrator_2_flux_distribution` 2D numpy image of efficiency as a function of angle of incidence.
* `concentrator_2_extent` Extent of the efficiency distribution on the form `(xmin, xmax, ymin, ymax)`, for plotting with `matplotlib.pyplot.imshow` The unit is milliradians.

## Underlying data for Fig. 8

Data underlying Fig. 8 is included as compressed numpy arrays in the `.npz` file format, in the file `Data/Fig_8.npz`. This file can be read using the `numpy.load` function.

The `.npz` file contains the following arrays

* `concentrator_1_flux_distribution` 2D numpy image of irradiance distribution, normalized to 1 sun. The x-axis is x-position normalized to the width of the concentrator. The y-axis is position around the tube, in degrees.
* `concentrator_1_extent` Extent of the flux distribution on the form `(xmin, xmax, ymin, ymax)`, for plotting with `matplotlib.pyplot.imshow`
* `concentrator_2_flux_distribution` 2D numpy image of irradiance distribution, normalized to 1 sun. The x-axis is x-position normalized to the width of the concentrator. The y-axis is position around the tube, in degrees.
* `concentrator_2_extent` Extent of the flux distribution on the form `(xmin, xmax, ymin, ymax)`, for plotting with `matplotlib.pyplot.imshow`